searchNodes=[{"ref":"Decimal.html","title":"Decimal","type":"module","doc":"Decimal arithmetic on arbitrary precision floating-point numbers. A number is represented by a signed coefficient and exponent such that: sign * coefficient * 10 ^ exponent. All numbers are represented and calculated exactly, but the result of an operation may be rounded depending on the context the operation is performed with, see: Decimal.Context. Trailing zeros in the coefficient are never truncated to preserve the number of significant digits unless explicitly done so. There are also special values such as NaN (not a number) and ±Infinity. -0 and +0 are two distinct values. Some operation results are not defined and will return NaN. This kind of NaN is quiet, any operation returning a number will return NaN when given a quiet NaN (the NaN value will flow through all operations). Exceptional conditions are grouped into signals, each signal has a flag and a trap enabler in the context. Whenever a signal is triggered it&#39;s flag is set in the context and will be set until explicitly cleared. If the signal is trap enabled Decimal.Error will be raised. Specifications IBM&#39;s General Decimal Arithmetic Specification IEEE standard 854-1987 This library follows the above specifications for reference of arithmetic operation implementations, but the public APIs may differ to provide a more idiomatic Elixir interface. The specification models the sign of the number as 1, for a negative number, and 0 for a positive number. Internally this implementation models the sign as 1 or -1 such that the complete number will be sign * coefficient * 10 ^ exponent and will refer to the sign in documentation as either positive or negative. There is currently no maximum or minimum values for the exponent. Because of that all numbers are &quot;normal&quot;. This means that when an operation should, according to the specification, return a number that &quot;underflows&quot; 0 is returned instead of Etiny. This may happen when dividing a number with infinity. Additionally, overflow, underflow and clamped may never be signalled."},{"ref":"Decimal.html#abs/1","title":"Decimal.abs/1","type":"function","doc":"The absolute value of given number. Sets the number&#39;s sign to positive."},{"ref":"Decimal.html#add/2","title":"Decimal.add/2","type":"function","doc":"Adds two numbers together. Exceptional conditions If one number is -Infinity and the other +Infinity, :invalid_operation will be signalled. Examples iex&gt; Decimal.add(1, &quot;1.1&quot;) #Decimal&lt;2.1&gt; iex&gt; Decimal.add(1, &quot;Inf&quot;) #Decimal&lt;Infinity&gt;"},{"ref":"Decimal.html#apply_context/1","title":"Decimal.apply_context/1","type":"function","doc":"Applies the context to the given number rounding it to specified precision."},{"ref":"Decimal.html#cast/1","title":"Decimal.cast/1","type":"function","doc":"Creates a new decimal number from an integer, string, float, or existing decimal number. Because conversion from a floating point number is not exact, it&#39;s recommended to instead use new/1 or from_float/1 when the argument&#39;s type is certain. See from_float/1. Examples iex&gt; {:ok, decimal} = Decimal.cast(3) iex&gt; decimal #Decimal&lt;3&gt; iex&gt; Decimal.cast(&quot;bad&quot;) :error"},{"ref":"Decimal.html#cmp/2","title":"Decimal.cmp/2","type":"function","doc":""},{"ref":"Decimal.html#compare/2","title":"Decimal.compare/2","type":"function","doc":"Compares two numbers numerically. If the first number is greater than the second :gt is returned, if less than :lt is returned, if both numbers are equal :eq is returned. Neither number can be a NaN. Examples iex&gt; Decimal.compare(&quot;1.0&quot;, 1) :eq iex&gt; Decimal.compare(&quot;Inf&quot;, -1) :gt"},{"ref":"Decimal.html#div/2","title":"Decimal.div/2","type":"function","doc":"Divides two numbers. Exceptional conditions If both numbers are ±Infinity :invalid_operation is signalled. If both numbers are ±0 :invalid_operation is signalled. If second number (denominator) is ±0 :division_by_zero is signalled. Examples iex&gt; Decimal.div(3, 4) #Decimal&lt;0.75&gt; iex&gt; Decimal.div(&quot;Inf&quot;, -1) #Decimal&lt;-Infinity&gt;"},{"ref":"Decimal.html#div_int/2","title":"Decimal.div_int/2","type":"function","doc":"Divides two numbers and returns the integer part. Exceptional conditions If both numbers are ±Infinity :invalid_operation is signalled. If both numbers are ±0 :invalid_operation is signalled. If second number (denominator) is ±0 :division_by_zero is signalled. Examples iex&gt; Decimal.div_int(5, 2) #Decimal&lt;2&gt; iex&gt; Decimal.div_int(&quot;Inf&quot;, -1) #Decimal&lt;-Infinity&gt;"},{"ref":"Decimal.html#div_rem/2","title":"Decimal.div_rem/2","type":"function","doc":"Integer division of two numbers and the remainder. Should be used when both div_int/2 and rem/2 is needed. Equivalent to: {Decimal.div_int(x, y), Decimal.rem(x, y)}. Exceptional conditions If both numbers are ±Infinity :invalid_operation is signalled. If both numbers are ±0 :invalid_operation is signalled. If second number (denominator) is ±0 :division_by_zero is signalled. Examples iex&gt; Decimal.div_rem(5, 2) {Decimal.new(2), Decimal.new(1)}"},{"ref":"Decimal.html#eq?/2","title":"Decimal.eq?/2","type":"function","doc":"Compares two numbers numerically and returns true if they are equal, otherwise false. If one of the operands is a quiet NaN this operation will always return false. Examples iex&gt; Decimal.eq?(&quot;1.0&quot;, 1) true iex&gt; Decimal.eq?(1, -1) false"},{"ref":"Decimal.html#equal?/2","title":"Decimal.equal?/2","type":"function","doc":"Compares two numbers numerically and returns true if they are equal, otherwise false. If one of the operands is a quiet NaN this operation will always return false. Examples iex&gt; Decimal.equal?(&quot;1.0&quot;, 1) true iex&gt; Decimal.equal?(1, -1) false"},{"ref":"Decimal.html#from_float/1","title":"Decimal.from_float/1","type":"function","doc":"Creates a new decimal number from a floating point number. Floating point numbers use a fixed number of binary digits to represent a decimal number which has inherent inaccuracy as some decimal numbers cannot be represented exactly in limited precision binary. Floating point numbers will be converted to decimal numbers with :io_lib_format.fwrite_g/1. Since this conversion is not exact and because of inherent inaccuracy mentioned above, we may run into counter-intuitive results: iex&gt; Enum.reduce([0.1, 0.1, 0.1], &amp;+/2) 0.30000000000000004 iex&gt; Enum.reduce([Decimal.new(&quot;0.1&quot;), Decimal.new(&quot;0.1&quot;), Decimal.new(&quot;0.1&quot;)], &amp;Decimal.add/2) #Decimal&lt;0.3&gt; For this reason, it&#39;s recommended to build decimals with new/1, which is always precise, instead. Examples iex&gt; Decimal.from_float(3.14) #Decimal&lt;3.14&gt;"},{"ref":"Decimal.html#gt?/2","title":"Decimal.gt?/2","type":"function","doc":"Compares two numbers numerically and returns true if the the first argument is greater than the second, otherwise false. If one the operands is a quiet NaN this operation will always return false. Examples iex&gt; Decimal.gt?(&quot;1.3&quot;, &quot;1.2&quot;) true iex&gt; Decimal.gt?(&quot;1.2&quot;, &quot;1.3&quot;) false"},{"ref":"Decimal.html#inf?/1","title":"Decimal.inf?/1","type":"function","doc":"Returns true if number is ±Infinity, otherwise false."},{"ref":"Decimal.html#is_decimal/1","title":"Decimal.is_decimal/1","type":"macro","doc":"Returns true if argument is a decimal number, otherwise false. Examples iex&gt; Decimal.is_decimal(Decimal.new(42)) true iex&gt; Decimal.is_decimal(42) false Allowed in guard tests on OTP 21+."},{"ref":"Decimal.html#lt?/2","title":"Decimal.lt?/2","type":"function","doc":"Compares two numbers numerically and returns true if the the first number is less than the second number, otherwise false. If one of the operands is a quiet NaN this operation will always return false. Examples iex&gt; Decimal.lt?(&quot;1.1&quot;, &quot;1.2&quot;) true iex&gt; Decimal.lt?(&quot;1.4&quot;, &quot;1.2&quot;) false"},{"ref":"Decimal.html#max/2","title":"Decimal.max/2","type":"function","doc":"Compares two values numerically and returns the maximum. Unlike most other functions in Decimal if a number is NaN the result will be the other number. Only if both numbers are NaN will NaN be returned. Examples iex&gt; Decimal.max(1, &quot;2.0&quot;) #Decimal&lt;2.0&gt; iex&gt; Decimal.max(1, &quot;NaN&quot;) #Decimal&lt;1&gt; iex&gt; Decimal.max(&quot;NaN&quot;, &quot;NaN&quot;) #Decimal&lt;NaN&gt;"},{"ref":"Decimal.html#min/2","title":"Decimal.min/2","type":"function","doc":"Compares two values numerically and returns the minimum. Unlike most other functions in Decimal if a number is NaN the result will be the other number. Only if both numbers are NaN will NaN be returned. Examples iex&gt; Decimal.min(1, &quot;2.0&quot;) #Decimal&lt;1&gt; iex&gt; Decimal.min(1, &quot;NaN&quot;) #Decimal&lt;1&gt; iex&gt; Decimal.min(&quot;NaN&quot;, &quot;NaN&quot;) #Decimal&lt;NaN&gt;"},{"ref":"Decimal.html#mult/2","title":"Decimal.mult/2","type":"function","doc":"Multiplies two numbers. Exceptional conditions If one number is ±0 and the other is ±Infinity :invalid_operation is signalled. Examples iex&gt; Decimal.mult(&quot;0.5&quot;, 3) #Decimal&lt;1.5&gt; iex&gt; Decimal.mult(&quot;Inf&quot;, -1) #Decimal&lt;-Infinity&gt;"},{"ref":"Decimal.html#nan?/1","title":"Decimal.nan?/1","type":"function","doc":"Returns true if number is NaN, otherwise false."},{"ref":"Decimal.html#negate/1","title":"Decimal.negate/1","type":"function","doc":"Negates the given number. Examples iex&gt; Decimal.negate(1) #Decimal&lt;-1&gt; iex&gt; Decimal.negate(&quot;-Inf&quot;) #Decimal&lt;Infinity&gt;"},{"ref":"Decimal.html#negative?/1","title":"Decimal.negative?/1","type":"function","doc":"Check if given number is negative"},{"ref":"Decimal.html#new/1","title":"Decimal.new/1","type":"function","doc":"Creates a new decimal number from an integer or a string representation. A decimal number will always be created exactly as specified with all digits kept - it will not be rounded with the context. Backus–Naur form sign ::= &quot;+&quot; | &quot;-&quot; digit ::= &quot;0&quot; | &quot;1&quot; | &quot;2&quot; | &quot;3&quot; | &quot;4&quot; | &quot;5&quot; | &quot;6&quot; | &quot;7&quot; | &quot;8&quot; | &quot;9&quot; indicator ::= &quot;e&quot; | &quot;E&quot; digits ::= digit [digit]... decimal-part ::= digits &quot;.&quot; [digits] | [&quot;.&quot;] digits exponent-part ::= indicator [sign] digits infinity ::= &quot;Infinity&quot; | &quot;Inf&quot; nan ::= &quot;NaN&quot; [digits] numeric-value ::= decimal-part [exponent-part] | infinity numeric-string ::= [sign] numeric-value | [sign] nan Floats See also from_float/1. Examples iex&gt; Decimal.new(1) #Decimal&lt;1&gt; iex&gt; Decimal.new(&quot;3.14&quot;) #Decimal&lt;3.14&gt;"},{"ref":"Decimal.html#new/3","title":"Decimal.new/3","type":"function","doc":"Creates a new decimal number from the sign, coefficient and exponent such that the number will be: sign * coefficient * 10 ^ exponent. A decimal number will always be created exactly as specified with all digits kept - it will not be rounded with the context."},{"ref":"Decimal.html#normalize/1","title":"Decimal.normalize/1","type":"function","doc":"Normalizes the given decimal: removes trailing zeros from coefficient while keeping the number numerically equivalent by increasing the exponent. Examples iex&gt; Decimal.normalize(Decimal.new(&quot;1.00&quot;)) #Decimal&lt;1&gt; iex&gt; Decimal.normalize(Decimal.new(&quot;1.01&quot;)) #Decimal&lt;1.01&gt;"},{"ref":"Decimal.html#parse/1","title":"Decimal.parse/1","type":"function","doc":"Parses a binary into a decimal. If successful, returns a tuple in the form of {decimal, remainder_of_binary}, otherwise :error. Examples iex&gt; Decimal.parse(&quot;3.14&quot;) {%Decimal{coef: 314, exp: -2, sign: 1}, &quot;&quot;} iex&gt; Decimal.parse(&quot;3.14.15&quot;) {%Decimal{coef: 314, exp: -2, sign: 1}, &quot;.15&quot;} iex&gt; Decimal.parse(&quot;-1.1e3&quot;) {%Decimal{coef: 11, exp: 2, sign: -1}, &quot;&quot;} iex&gt; Decimal.parse(&quot;bad&quot;) :error"},{"ref":"Decimal.html#positive?/1","title":"Decimal.positive?/1","type":"function","doc":"Check if given number is positive"},{"ref":"Decimal.html#rem/2","title":"Decimal.rem/2","type":"function","doc":"Remainder of integer division of two numbers. The result will have the sign of the first number. Exceptional conditions If both numbers are ±Infinity :invalid_operation is signalled. If both numbers are ±0 :invalid_operation is signalled. If second number (denominator) is ±0 :division_by_zero is signalled. Examples iex&gt; Decimal.rem(5, 2) #Decimal&lt;1&gt;"},{"ref":"Decimal.html#round/3","title":"Decimal.round/3","type":"function","doc":"Rounds the given number to specified decimal places with the given strategy (default is to round to nearest one). If places is negative, at least that many digits to the left of the decimal point will be zero. See Decimal.Context for more information about rounding algorithms. Examples iex&gt; Decimal.round(&quot;1.234&quot;) #Decimal&lt;1&gt; iex&gt; Decimal.round(&quot;1.234&quot;, 1) #Decimal&lt;1.2&gt;"},{"ref":"Decimal.html#sqrt/1","title":"Decimal.sqrt/1","type":"function","doc":"Finds the square root. Examples iex&gt; Decimal.sqrt(&quot;100&quot;) #Decimal&lt;10&gt;"},{"ref":"Decimal.html#sub/2","title":"Decimal.sub/2","type":"function","doc":"Subtracts second number from the first. Equivalent to Decimal.add/2 when the second number&#39;s sign is negated. Exceptional conditions If one number is -Infinity and the other +Infinity :invalid_operation will be signalled. Examples iex&gt; Decimal.sub(1, &quot;0.1&quot;) #Decimal&lt;0.9&gt; iex&gt; Decimal.sub(1, &quot;Inf&quot;) #Decimal&lt;-Infinity&gt;"},{"ref":"Decimal.html#to_float/1","title":"Decimal.to_float/1","type":"function","doc":"Returns the decimal converted to a float. The returned float may have lower precision than the decimal. Fails if the decimal cannot be converted to a float."},{"ref":"Decimal.html#to_integer/1","title":"Decimal.to_integer/1","type":"function","doc":"Returns the decimal represented as an integer. Fails when loss of precision will occur."},{"ref":"Decimal.html#to_string/2","title":"Decimal.to_string/2","type":"function","doc":"Converts given number to its string representation. Options :scientific - number converted to scientific notation. :normal - number converted without a exponent. :xsd - number converted to the canonical XSD representation. :raw - number converted to its raw, internal format."},{"ref":"Decimal.html#t:coefficient/0","title":"Decimal.coefficient/0","type":"type","doc":"The coefficient of the power of 10. Non-negative because the sign is stored separately in sign. non_neg_integer - when the t represents a number, instead of one of the special values below. :NaN - Not a Number. :inf - Infinity."},{"ref":"Decimal.html#t:decimal/0","title":"Decimal.decimal/0","type":"type","doc":""},{"ref":"Decimal.html#t:exponent/0","title":"Decimal.exponent/0","type":"type","doc":"The exponent to which 10 is raised."},{"ref":"Decimal.html#t:rounding/0","title":"Decimal.rounding/0","type":"type","doc":"Rounding algorithm. See Decimal.Context for more information."},{"ref":"Decimal.html#t:sign/0","title":"Decimal.sign/0","type":"type","doc":"1 for positive -1 for negative"},{"ref":"Decimal.html#t:signal/0","title":"Decimal.signal/0","type":"type","doc":""},{"ref":"Decimal.html#t:t/0","title":"Decimal.t/0","type":"type","doc":"This implementation models the sign as 1 or -1 such that the complete number will be: sign * coef * 10 ^ exp. coef - the coefficient of the power of 10. exp - the exponent of the power of 10. sign - 1 for positive, -1 for negative."},{"ref":"Decimal.Context.html","title":"Decimal.Context","type":"module","doc":"The context is kept in the process dictionary. It can be accessed with get/0 and set/1. The default context has a precision of 28, the rounding algorithm is :half_up. The set trap enablers are :invalid_operation and :division_by_zero. Fields precision - maximum number of decimal digits in the coefficient. If an operation result has more digits it will be rounded to precision digits with the rounding algorithm in rounding. rounding - the rounding algorithm used when the coefficient&#39;s number of exceeds precision. Strategies explained below. flags - a list of signals that for which the flag is sent. When an exceptional condition is signalled its flag is set. The flags are sticky and will be set until explicitly cleared. traps - a list of set trap enablers for signals. When a signal&#39;s trap enabler is set the condition causes Decimal.Error to be raised. Rounding algorithms :down - round toward zero (truncate). Discarded digits are ignored, result is unchanged. :half_up - if the discarded digits is greater than or equal to half of the value of a one in the next left position then the coefficient will be incremented by one (rounded up). Otherwise (the discarded digits are less than half) the discarded digits will be ignored. :half_even - also known as &quot;round to nearest&quot; or &quot;banker&#39;s rounding&quot;. If the discarded digits is greater than half of the value of a one in the next left position then the coefficient will be incremented by one (rounded up). If they represent less than half discarded digits will be ignored. Otherwise (exactly half), the coefficient is not altered if it&#39;s even, or incremented by one (rounded up) if it&#39;s odd (to make an even number). :ceiling - round toward +Infinity. If all of the discarded digits are zero or the sign is negative the result is unchanged. Otherwise, the coefficient will be incremented by one (rounded up). :floor - round toward -Infinity. If all of the discarded digits are zero or the sign is positive the result is unchanged. Otherwise, the sign is negative and coefficient will be incremented by one. :half_down - if the discarded digits is greater than half of the value of a one in the next left position then the coefficient will be incremented by one (rounded up). Otherwise (the discarded digits are half or less) the discarded digits are ignored. :up - round away from zero. If all discarded digits are zero the coefficient is not changed, otherwise it is incremented by one (rounded up). This table shows the results of rounding operations for all the rounding algorithms: Rounding algorithm5.52.51.61.11.0-1.0-1.1-1.6-2.5-5.5 :up63221-1-2-2-3-6 :down52111-1-1-1-2-5 :ceiling63221-1-1-1-2-5 :floor52111-1-2-2-3-6 :half_up63211-1-1-2-3-6 :half_down52211-1-1-2-2-5 :half_even62211-1-1-2-2-6"},{"ref":"Decimal.Context.html#get/0","title":"Decimal.Context.get/0","type":"function","doc":"Gets the process&#39; context."},{"ref":"Decimal.Context.html#set/1","title":"Decimal.Context.set/1","type":"function","doc":"Set the process&#39; context."},{"ref":"Decimal.Context.html#update/1","title":"Decimal.Context.update/1","type":"function","doc":"Update the process&#39; context."},{"ref":"Decimal.Context.html#with/2","title":"Decimal.Context.with/2","type":"function","doc":"Runs function with given context."},{"ref":"Decimal.Context.html#t:t/0","title":"Decimal.Context.t/0","type":"type","doc":""},{"ref":"Decimal.Error.html","title":"Decimal.Error","type":"exception","doc":"The exception that all decimal operations may raise. Fields signal - the signalled error, additional signalled errors will be found in the context. reason - the reason for the error. Rescuing the error to access the result or the other fields of the error is discouraged and should only be done for exceptional conditions. It is more pragmatic to set the appropriate traps on the context and check the flags after the operation if the result needs to be inspected."},{"ref":"readme.html","title":"Decimal","type":"extras","doc":"Decimal Arbitrary precision decimal arithmetic. Documentation: https://hexdocs.pm/decimal/"},{"ref":"readme.html#usage","title":"Decimal - Usage","type":"extras","doc":"Add Decimal as a dependency in your mix.exs file. def deps do [{:decimal, &quot;~&gt; 1.0&quot;}] end After you are done, run mix deps.get in your shell to fetch and compile Decimal. Start an interactive Elixir shell with iex -S mix. iex&gt; alias Decimal, as: D iex&gt; D.add(6, 7) #Decimal&lt;13&gt; iex&gt; D.div(1, 3) #Decimal&lt;0.333333333&gt; iex&gt; D.new(&quot;0.33&quot;) #Decimal&lt;0.33&gt;"},{"ref":"readme.html#examples","title":"Decimal - Examples","type":"extras","doc":"Using the context The context specifies the maximum precision of the result of calculations and the rounding algorithm if the result has a higher precision than the specified maximum. It also holds the list of set of trap enablers and the currently set flags. The context is stored in the process dictionary, this means that you don&#39;t have to pass the context around explicitly and the flags will be updated automatically. The context is accessed with Decimal.Context.get/0 and set with Decimal.Context.set/1. It can also be temporarily set with Decimal.Context.with/2. iex&gt; D.Context.get() %Decimal.Context{flags: [:rounded, :inexact], precision: 9, rounding: :half_up, traps: [:invalid_operation, :division_by_zero]} iex&gt; D.Context.with(%D.Context{precision: 2}, fn -&gt; IO.inspect D.Context.get() end) %Decimal.Context{flags: [], precision: 2, rounding: :half_up, traps: [:invalid_operation, :division_by_zero]} %Decimal.Context{flags: [], precision: 2, rounding: :half_up, traps: [:invalid_operation, :division_by_zero]} iex&gt; D.Context.set(%D.Context{D.Context.get() | traps: []}) :ok iex&gt; D.Context.get() %Decimal.Context{flags: [:rounded, :inexact], precision: 9, rounding: :half_up, traps: []} Precision and rounding The precision is used to limit the amount of decimal digits in the coefficient: iex&gt; D.Context.set(%D.Context{D.Context.get() | precision: 9}) :ok iex&gt; D.div(100, 3) #Decimal&lt;33.3333333&gt; iex&gt; D.Context.set(%D.Context{D.Context.get() | precision: 2}) :ok iex&gt; D.div(100, 3) #Decimal&lt;33&gt; The rounding algorithm specifies how the result of an operation shall be rounded when it get be represented with the current precision: iex&gt; D.Context.set(%D.Context{D.Context.get() | rounding: :half_up}) :ok iex&gt; D.div(31, 2) #Decimal&lt;16&gt; iex&gt; D.Context.set(%D.Context{D.Context.get() | rounding: :floor}) :ok iex&gt; D.div(31, 2) #Decimal&lt;15&gt; Comparisons Using compare operators (&lt;, =, &gt;) directly with two decimals may not return the correct result. Instead use comparison functions. iex&gt; D.cmp(-1, 0) :lt iex&gt; D.cmp(0, -1) :gt iex&gt; D.cmp(0, 0) :eq iex&gt; D.equal?(-1, 0) false iex&gt; D.equal?(0, &quot;0.0&quot;) true Flags and trap enablers When an exceptional condition is signalled its flag is set in the context and if if the trap enabler is set Decimal.Error will be raised. iex&gt; D.Context.set(%D.Context{D.Context.get() | rounding: :floor, precision: 2}) :ok iex&gt; D.Context.get().traps [:invalid_operation, :division_by_zero] iex&gt; D.Context.get().flags [] iex&gt; D.div(31, 2) #Decimal&lt;15&gt; iex&gt; D.Context.get().flags [:inexact, :rounded] :inexact and :rounded were signaled above because the result of the operation was inexact given the context&#39;s precision and had to be rounded to fit the precision. Decimal.Error was not raised because the signals&#39; trap enablers weren&#39;t set. We can, however, set the trap enabler if we what this condition to raise. iex&gt; D.Context.set(%D.Context{D.Context.get() | traps: D.Context.get().traps ++ [:inexact]}) :ok iex&gt; D.div(31, 2) ** (Decimal.Error) The default trap enablers, such as :division_by_zero can be unset: iex&gt; D.Context.get().traps [:invalid_operation, :division_by_zero] iex&gt; D.div(42, 0) ** (Decimal.Error) iex&gt; D.Context.set(%D.Context{D.Context.get() | traps: [], flags: []}) :ok iex&gt; D.div(42, 0) #Decimal&lt;Infinity&gt; iex&gt; D.Context.get().flags [:division_by_zero] Mitigating rounding errors TODO"},{"ref":"readme.html#license","title":"Decimal - License","type":"extras","doc":"Copyright 2013 Eric Meadows-Jönsson Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License."}]